This is a library of python functions that support the Cambio suite of codes for modeling Earth's climate.

# Installation
This has been packaged on PyPI. To install, run
```sh
python -m pip install meclib
```

# Usage
See examples in the examples folder.
